/****************************************************************/
/* FILENAME: main_1241.c                            		*/
/* DESCRIPTION: This program uses the MSP430F449 to read  	*/
/*    samples from the ADS1241 test board.                      */
/*    The samples are display on the LCD Screen.                */
/*  Samples can also be displayed through a terminal program    */
/*    provided that the HPA449 is set for RS232 and JTAG comm.  */
/*    as depicted in the HPA449 UG pg. 25 sec 4.3 - find the UG */
/*    at www.softbaugh.com/downloads/HPA449_UsersGuide.pdf      */
/*  AUTHOR: T. Hendrick, Data Acquisition Products,             */
/*    Dallas Texas                                              */
/*    CREATED 2005(C) BY TEXAS INSTRUMENTS INCORPORATED.  	*/
/*    VERSION: A 						*/
/****************************************************************/
#include <msp430x44x.h>
#include <math.h>
#include "hpa449lib.h"
#include "ADS1240.h"
#define Resonator (0)  //Default - HPA449 ships with no resonator at X4

/************************************************************************/
/*                                                                      */
/* Global variable declarations                                         */
/*                                                                      */
/************************************************************************/

static char HexTable[] =
   {
      '0','1','2','3','4','5','6','7',
      '8','9','a','b','c','d','e','f'
   };

/******************************************************************************
** [function]
** Output24BitASCII
** [purpose]
** sends 24-bit number as hex number in ASCII over serial port
** [parameters]
** Data, 24-bit long
** [returns]
** -
*/
void Output24BitASCII(long Data)
{
   char Buffer[6];
   int i;

   for (i=5; i>=0; i--)
   {
       Buffer[i] = HexTable[Data & 0x0000000f];
       Data >>= 4;
   }
   // display data on HPA449 screen
   sblcd_lg_showstr(Buffer);
   SendBytes(Buffer, 6);
}

/******************************************************************************
** [function]
** Init
** [purpose]
** Sets GPIO through port extender, initialize the UART function
** [parameters]
** none
** [returns]
** void
*/
void Init(void)
{
  I2C_Init();
  setupClock(0);
  sblcd_init();
  ADS1240Init();
   // initialize the communication port
   UART1_Init(42, 0x6b);	// sets baud rate to 115.2k
   // enable interrupts (out buffered serial routine uses them)
   _EINT();
}

/******************************************************************************
** [function]
** Main
** [purpose]
** Gets initialization done, runs eternal sample loop
** [parameters]
** -
** [returns]
** -
*/
void main(void)
{ // Some initialization routines:
  int i;
  long Data;
  unsigned ACRVal;
  int chan = 0;
  char chdisp[4];
  Init();
  // Begin main program:
  ADS1240SendResetCommand();
  ADS1240SetGain(ADS1240_GAIN_1);
  ADS1240SetChannel(chan | ADS1240_MUXN_AINCOM);
  // data rate = 15Hz (4.91MHz, SPEED = 1)
  ACRVal = SPEED_BIT;
  chdisp[0] = 'c';
  chdisp[1] = 'h';
  chdisp[2] = ' ';
  chdisp[3] = '0';
  sblcd_sm_showstr(chdisp);
  ADS1240WriteRegister(ADS1240_ACR_REGISTER, 1, &ACRVal);
  ADS1240AssertCS(1);
  ADS1240SendByte(ADS1240_CMD_SELFCAL);
  ADS1240AssertCS(0);
  for (i=0; i<4; i++);
  ADS1240WaitForDataReady(0);
  // Start forever loop:
  while (1)
  {
    // acquire data
    Data = ADS1240ReadData(1);
    // send hex value of data to HPA449 screen and to serial port
    Output24BitASCII(Data);
    SendString("\r\n");
    Pause(50);
    //  The "if loop" is entered upon SW2 press detection		
      if (!(P1IN & SWITCH_2_BIT))
      {
        while (!(P1IN & SWITCH_2_BIT));
		chan++;
	if (chan == 8){chan = 0;}
	chdisp[3] = HexTable[chan];
	//display current channel on small LCD and serial port
	sblcd_sm_showstr(chdisp);
			
	ADS1240SetChannel((chan*0x10) | ADS1240_MUXN_AINCOM);
			
	// do an internal self cal
	ADS1240AssertCS(1);
	ADS1240SendByte(ADS1240_CMD_SELFCAL);
	ADS1240AssertCS(0);
	for (i=0; i<4; i++)
	ADS1240WaitForDataReady(0);
      }
  }
}			      	








